@@ -884,6 +884,11 @@ data EventControllerScrollFlags =
     -- ^ Only emit deltas that are multiples of 1.
     | EventControllerScrollFlagsKinetic
     -- ^ Emit [decelerate](#g:signal:decelerate) after continuous scroll finishes.
+    | EventControllerScrollFlagsPhysicalDirection
+    -- ^ A t'GI.Gtk.Flags.EventControllerScrollFlags' value to prefer physical direction over
+    -- logical direction (i.e. oblivious to natural scroll).
+    -- 
+    -- /Since: 4.20/
     | EventControllerScrollFlagsBothAxes
     -- ^ Emit scroll on both axes.
     | AnotherEventControllerScrollFlags Int
@@ -896,6 +901,7 @@ instance P.Enum EventControllerScrollFlags where
     fromEnum EventControllerScrollFlagsHorizontal = 2
     fromEnum EventControllerScrollFlagsDiscrete = 4
     fromEnum EventControllerScrollFlagsKinetic = 8
+    fromEnum EventControllerScrollFlagsPhysicalDirection = 16
     fromEnum EventControllerScrollFlagsBothAxes = 3
     fromEnum (AnotherEventControllerScrollFlags k) = k
 
@@ -904,6 +910,7 @@ instance P.Enum EventControllerScrollFlags where
     toEnum 2 = EventControllerScrollFlagsHorizontal
     toEnum 4 = EventControllerScrollFlagsDiscrete
     toEnum 8 = EventControllerScrollFlagsKinetic
+    toEnum 16 = EventControllerScrollFlagsPhysicalDirection
     toEnum 3 = EventControllerScrollFlagsBothAxes
     toEnum k = AnotherEventControllerScrollFlags k
 
@@ -987,13 +994,17 @@ data DebugFlags =
     | DebugFlagsPrinting
     -- ^ Information about printing
     | DebugFlagsBuilderTrace
-    -- ^ /No description available in the introspection data./
+    -- ^ Trace GtkBuilder operation
     | DebugFlagsSizeRequest
     -- ^ Information about size requests
     | DebugFlagsNoCssCache
     -- ^ Disable the style property cache
     | DebugFlagsInteractive
     -- ^ Open the GTK inspector
+    | DebugFlagsTouchscreen
+    -- ^ Show touch UI elements for pointer events.
+    -- 
+    -- /Since: 4.20/
     | DebugFlagsActions
     -- ^ Information about actions and menu models
     | DebugFlagsLayout
@@ -1019,7 +1030,9 @@ data DebugFlags =
     -- 
     -- /Since: 4.16/
     | DebugFlagsBuilder
-    -- ^ Trace GtkBuilder operation
+    -- ^ Information about deprecated GtkBuilder features.
+    -- 
+    -- /Since: 4.18/
     | AnotherDebugFlags Int
     -- ^ Catch-all for unknown values
     deriving (Show, Eq)
@@ -1036,6 +1049,7 @@ instance P.Enum DebugFlags where
     fromEnum DebugFlagsSizeRequest = 256
     fromEnum DebugFlagsNoCssCache = 512
     fromEnum DebugFlagsInteractive = 1024
+    fromEnum DebugFlagsTouchscreen = 2048
     fromEnum DebugFlagsActions = 4096
     fromEnum DebugFlagsLayout = 8192
     fromEnum DebugFlagsSnapshot = 16384
@@ -1059,6 +1073,7 @@ instance P.Enum DebugFlags where
     toEnum 256 = DebugFlagsSizeRequest
     toEnum 512 = DebugFlagsNoCssCache
     toEnum 1024 = DebugFlagsInteractive
+    toEnum 2048 = DebugFlagsTouchscreen
     toEnum 4096 = DebugFlagsActions
     toEnum 8192 = DebugFlagsLayout
     toEnum 16384 = DebugFlagsSnapshot
