@@ -455,6 +455,7 @@ instance AttrInfo FontChooserFontPropertyInfo where
     type AttrOrigin FontChooserFontPropertyInfo = FontChooser
     attrGet = getFontChooserFont
     attrSet = setFontChooserFont
+    attrPut = undefined
     attrTransfer _ v = do
         return v
     attrConstruct = constructFontChooserFont
@@ -507,6 +508,7 @@ instance AttrInfo FontChooserFontDescPropertyInfo where
     type AttrOrigin FontChooserFontDescPropertyInfo = FontChooser
     attrGet = getFontChooserFontDesc
     attrSet = setFontChooserFontDesc
+    attrPut = undefined
     attrTransfer _ v = do
         return v
     attrConstruct = constructFontChooserFontDesc
@@ -544,6 +546,7 @@ instance AttrInfo FontChooserFontFeaturesPropertyInfo where
     type AttrOrigin FontChooserFontFeaturesPropertyInfo = FontChooser
     attrGet = getFontChooserFontFeatures
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ = undefined
     attrConstruct = undefined
     attrClear = undefined
@@ -595,6 +598,7 @@ instance AttrInfo FontChooserLanguagePropertyInfo where
     type AttrOrigin FontChooserLanguagePropertyInfo = FontChooser
     attrGet = getFontChooserLanguage
     attrSet = setFontChooserLanguage
+    attrPut = undefined
     attrTransfer _ v = do
         return v
     attrConstruct = constructFontChooserLanguage
@@ -637,7 +641,7 @@ constructFontChooserLevel val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data FontChooserLevelPropertyInfo
 instance AttrInfo FontChooserLevelPropertyInfo where
-    type AttrAllowedOps FontChooserLevelPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps FontChooserLevelPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint FontChooserLevelPropertyInfo = IsFontChooser
     type AttrSetTypeConstraint FontChooserLevelPropertyInfo = (~) [Gtk.Flags.FontChooserLevel]
     type AttrTransferTypeConstraint FontChooserLevelPropertyInfo = (~) [Gtk.Flags.FontChooserLevel]
@@ -647,6 +651,7 @@ instance AttrInfo FontChooserLevelPropertyInfo where
     type AttrOrigin FontChooserLevelPropertyInfo = FontChooser
     attrGet = getFontChooserLevel
     attrSet = setFontChooserLevel
+    attrPut = setFontChooserLevel
     attrTransfer _ v = do
         return v
     attrConstruct = constructFontChooserLevel
@@ -699,6 +704,7 @@ instance AttrInfo FontChooserPreviewTextPropertyInfo where
     type AttrOrigin FontChooserPreviewTextPropertyInfo = FontChooser
     attrGet = getFontChooserPreviewText
     attrSet = setFontChooserPreviewText
+    attrPut = undefined
     attrTransfer _ v = do
         return v
     attrConstruct = constructFontChooserPreviewText
@@ -741,7 +747,7 @@ constructFontChooserShowPreviewEntry val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data FontChooserShowPreviewEntryPropertyInfo
 instance AttrInfo FontChooserShowPreviewEntryPropertyInfo where
-    type AttrAllowedOps FontChooserShowPreviewEntryPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps FontChooserShowPreviewEntryPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint FontChooserShowPreviewEntryPropertyInfo = IsFontChooser
     type AttrSetTypeConstraint FontChooserShowPreviewEntryPropertyInfo = (~) Bool
     type AttrTransferTypeConstraint FontChooserShowPreviewEntryPropertyInfo = (~) Bool
@@ -751,6 +757,7 @@ instance AttrInfo FontChooserShowPreviewEntryPropertyInfo where
     type AttrOrigin FontChooserShowPreviewEntryPropertyInfo = FontChooser
     attrGet = getFontChooserShowPreviewEntry
     attrSet = setFontChooserShowPreviewEntry
+    attrPut = setFontChooserShowPreviewEntry
     attrTransfer _ v = do
         return v
     attrConstruct = constructFontChooserShowPreviewEntry
