@@ -371,6 +371,7 @@ instance AttrInfo ATContextAccessiblePropertyInfo where
     type AttrOrigin ATContextAccessiblePropertyInfo = ATContext
     attrGet = getATContextAccessible
     attrSet = undefined
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gtk.Accessible.Accessible v
     attrConstruct = constructATContextAccessible
@@ -413,7 +414,7 @@ constructATContextAccessibleRole val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ATContextAccessibleRolePropertyInfo
 instance AttrInfo ATContextAccessibleRolePropertyInfo where
-    type AttrAllowedOps ATContextAccessibleRolePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ATContextAccessibleRolePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ATContextAccessibleRolePropertyInfo = IsATContext
     type AttrSetTypeConstraint ATContextAccessibleRolePropertyInfo = (~) Gtk.Enums.AccessibleRole
     type AttrTransferTypeConstraint ATContextAccessibleRolePropertyInfo = (~) Gtk.Enums.AccessibleRole
@@ -423,6 +424,7 @@ instance AttrInfo ATContextAccessibleRolePropertyInfo where
     type AttrOrigin ATContextAccessibleRolePropertyInfo = ATContext
     attrGet = getATContextAccessibleRole
     attrSet = setATContextAccessibleRole
+    attrPut = setATContextAccessibleRole
     attrTransfer _ v = do
         return v
     attrConstruct = constructATContextAccessibleRole
@@ -484,6 +486,7 @@ instance AttrInfo ATContextDisplayPropertyInfo where
     type AttrOrigin ATContextDisplayPropertyInfo = ATContext
     attrGet = getATContextDisplay
     attrSet = setATContextDisplay
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gdk.Display.Display v
     attrConstruct = constructATContextDisplay
